# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-12-19 12:57
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_mission', '0014_auto_20181130_1533'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='mission',
            options={'ordering': ['created_at'], 'permissions': (('view_mission_list', '\u67e5\u770b\u4efb\u52a1\u5217\u8868'),)},
        ),
        migrations.AlterModelOptions(
            name='stage',
            options={'ordering': ['level'], 'permissions': (('view_stage_list', '\u67e5\u770b\u9636\u6bb5\u5217\u8868'),)},
        ),
    ]
