# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-11-30 05:46
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_mission', '0012_auto_20181129_1444'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='mission',
            options={'ordering': ['created_at']},
        ),
    ]
