{% load bee_django_mission_filter %}
<div class="progress">
  <div class="progress-bar progress-bar-success progress-bar-striped" role="progressbar" aria-valuenow="60" aria-valuemin="0" aria-valuemax="100" style="width:{{ p.3}}%;min-width: 2em;">
{#      {{ user_mission.get_user_mission_progress|multiple:100}}%#}
  </div>

</div>
<div style="margin-top: -10px;">({{ p.1}}/{{ p.2}})</div>