{% extends "bee_django_mission/custom_base.html" %}
{% load bee_django_mission_filter %}

{% block content %}
    {#    路径导航#}
    {#    <ol class="breadcrumb">#}
    {#        <li><a href="#">Home</a></li>#}
    {#        <li><a href="#">Library</a></li>#}
    {#        <li class="active">Data</li>#}
    {#    </ol>#}
    {#    #}
    {#    分类菜单#}
    <div class="btn-group" role="group" style="margin: 20px 0;">
        <a class="btn btn-default"
           href="{% url 'bee_django_mission:custom_user_line_week' user_id=request.user.id %}">周任务</a>
        <a class="btn btn-success active">里程碑</a>
    </div>
    {#任务列表#}
    <div>
        <div class="dropdown">
            <button class="btn btn-default dropdown-toggle" type="button" id="dropdownMenu2" data-toggle="dropdown"
                    aria-haspopup="true" aria-expanded="false">
                {{ user_stage.user_line.line.name }}列表
                <span class="caret"></span>
            </button>
            <ul class="dropdown-menu" aria-labelledby="dropdownMenu2">
                {% for u_s in user_stage_list %}
                    <li><a href="{% url 'bee_django_mission:custom_user_stage_detail' u_s.id %}">{{ u_s.get_name }}</a></li>
                {% endfor %}
            </ul>
        </div>
    </div>

    {% include 'bee_django_mission/user/mission/include/list.html' %}
{% endblock %}
